@@ -1,4 +1,8 @@
 """
+# Copyright (c) 2020 CNES
+#
+# All rights reserved. Use of this source code is governed by a
+# BSD-style license that can be found in the LICENSE file.
 Get software version information
 ================================
 """
@@ -6,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.0.8"
+    return "0.1.0"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "07 December 2019"
+    return "04 January 2020"
